| Title: | Analyze and Visualize FAST-Generated Data |
|---|---|
| Description: | R 'shiny' app to perform data analysis and visualization for the Fully Automated Senescence Test (FAST) workflow. |
| Authors: | Francesco Neri [aut, cre, cph] (ORCID: <https://orcid.org/0000-0001-6818-684X>) |
| Maintainer: | Francesco Neri <[email protected]> |
| License: | Apache License (>= 2) |
| Version: | 0.2.1.9000 |
| Built: | 2026-06-08 09:54:42 UTC |
| Source: | https://github.com/f-neri/fast.r |
R shiny app to perform data analysis and visualization for the Fully Automated Senescence Test (FAST) workflow.
FAST.R(Browser = FALSE)FAST.R(Browser = FALSE)
Browser |
Logical. If TRUE, FAST.R will open in a browser window |
Launches an R shiny app to analyze and visualize data generated with the FAST workflow
if(interactive()){FAST.R()}if(interactive()){FAST.R()}